#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dhall
version:              1.42.3
visibility:           public
id:                   dhall-1.42.3-8DeXK9s2q9L5zhyLLTq6Ly
key:                  dhall-1.42.3-8DeXK9s2q9L5zhyLLTq6Ly
license:              BSD-3-Clause
copyright:            2017 Gabriella Gonzalez
maintainer:           GenuineGabriella@gmail.com
author:               Gabriella Gonzalez
synopsis:             A configuration language guaranteed to terminate
description:
    Dhall is an explicitly typed configuration language that is not Turing
    complete.  Despite being Turing incomplete, Dhall is a real programming
    language with a type-checker and evaluator.

    Use this library to parse, type-check, evaluate, and pretty-print the Dhall
    configuration language.  This package also includes an executable which
    type-checks a Dhall file and reduces the file to a fully evaluated normal
    form.

    Read "Dhall.Tutorial" to learn how to use this library

category:             Compiler
abi:                  f6dc2d99736fc14bcc51ce0890395ae7
exposed:              True
exposed-modules:
    Dhall Dhall.Binary Dhall.Context Dhall.Core Dhall.Crypto
    Dhall.Deriving Dhall.Diff Dhall.DirectoryTree Dhall.Format
    Dhall.Freeze Dhall.Import Dhall.Lint Dhall.Main Dhall.Map
    Dhall.Marshal.Decode Dhall.Marshal.Encode Dhall.Optics
    Dhall.Package Dhall.Parser Dhall.Parser.Expression
    Dhall.Parser.Token Dhall.Pretty Dhall.Repl Dhall.Schemas Dhall.Set
    Dhall.Src Dhall.Substitution Dhall.TH Dhall.Tags Dhall.Tutorial
    Dhall.TypeCheck Dhall.Util Dhall.Version

hidden-modules:
    Dhall.DirectoryTree.Types Dhall.Eval Dhall.Import.Types
    Dhall.Import.Headers Dhall.Marshal.Internal Dhall.Normalize
    Dhall.Parser.Combinators Dhall.Pretty.Internal Dhall.Syntax
    Dhall.Syntax.Binding Dhall.Syntax.Chunks Dhall.Syntax.Const
    Dhall.Syntax.Expr Dhall.Syntax.FunctionBinding Dhall.Syntax.Import
    Dhall.Syntax.Instances.Applicative Dhall.Syntax.Instances.Bifunctor
    Dhall.Syntax.Instances.Data Dhall.Syntax.Instances.Eq
    Dhall.Syntax.Instances.Foldable Dhall.Syntax.Instances.Functor
    Dhall.Syntax.Instances.Lift Dhall.Syntax.Instances.Monad
    Dhall.Syntax.Instances.NFData Dhall.Syntax.Instances.Ord
    Dhall.Syntax.Instances.Pretty Dhall.Syntax.Instances.Show
    Dhall.Syntax.Instances.Traversable Dhall.Syntax.MultiLet
    Dhall.Syntax.Operations Dhall.Syntax.RecordField Dhall.Syntax.Types
    Dhall.Syntax.Var Dhall.URL Paths_dhall Dhall.Import.HTTP
    Dhall.Import.Manager

import-dirs:          /usr/lib/ghc-9.6.6/site-local/dhall-1.42.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/dhall-1.42.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/dhall-1.42.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/dhall
hs-libraries:         HSdhall-1.42.3-8DeXK9s2q9L5zhyLLTq6Ly
depends:
    Diff-0.5-fNSHrsymP36dtk0YqFhZ1 aeson-2.2.1.0-1TOI5ELuqi01VCY8v7ADie
    aeson-pretty-0.8.10-4OOIZnvRBsOBRwfw3s16jW
    ansi-terminal-1.1-6lZFbttD1pdJPhvO6TaL8q
    atomic-write-0.2.1.1-BpXI6yghI9888y6D2GCtlt base-4.18.2.1
    base16-bytestring-1.0.2.0-LP56PDIB6UDLEDCWqOwifx
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-GQhuCOunwpP4Wu7eC91bZR
    cborg-0.2.10.0-KJcPKMBW1MI1JWpLuCsNzi
    cborg-json-0.2.6.0-GTzC0kALDV3DPQfvPQWAHt containers-0.6.7
    contravariant-1.5.6-DrebhAx4XwC59wq9S42cYg
    cryptohash-sha256-0.11.102.1-Iz9MD1E47hHAwm4FqCNeNY
    data-fix-0.3.4-KFZEWXtL3G756hnKa4LQgj deepseq-1.4.8.1
    directory-1.3.8.5 dotgen-0.4.3-A2UTkkV6Fes7fbL6Rpf3sY
    either-5.0.3-DJfTESfI3pa1Kspx8z8l8o exceptions-0.10.7
    filepath-1.4.300.1 half-0.3.3-4Nx2MMnfdz53IpuTksVAsN
    hashable-1.4.7.0-CNoNcGLK9KJ5X5nXfJeai3 haskeline-0.8.2.1
    http-client-0.7.19-A1qGvj2MlivKXlcAABR34l
    http-client-tls-0.3.6.4-63NdgoH5NGbC0F7SbjBwuZ
    http-types-0.12.4-CCQmPdMOAQMGVpO7SZrjGJ
    indexed-traversable-0.1.4-8j5HZpShpE5BqFup9Ojenr
    megaparsec-9.7.0-HwFCj8AZlAe6hd0TjBRiui
    microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3
    microlens-mtl-0.2.1.0-Ewo8HmKpWhTASatFX3KZGS
    mmorph-1.2.2-I879kMQXeoiA7V1mSxl9UH mtl-2.3.1
    network-uri-2.6.4.2-F4vpljQpQbT2777eQcDCfi
    optparse-applicative-0.18.1.0-EpSL3bYuMS8I8b55RDM0x
    parser-combinators-1.3.1-8aQ8dKOwDVmFxT1S1WvW6m
    parsers-0.12.12-Ge05T8EnSWDBY9x8gqPh63
    pretty-simple-4.1.4.0-GGv7P7mwo9o6zCSyVMPXL9
    prettyprinter-1.7.1-DrhJgh2zvVyDSlphpqlv9X
    prettyprinter-ansi-terminal-1.1.3-4NBKkPa3YgEBUirxYRzZyb
    repline-0.4.3.0-8K1qOV9c7aG2gqDtsaBJvy
    scientific-0.3.8.1-9lNiUg0NFGt8fB4Ap5FVsD
    serialise-0.2.6.1-81ubGBCOmt6JKql2yiZwIR template-haskell-2.20.0.0
    text-2.0.2 text-manipulate-0.3.1.0-LLbHZl9qqeJBxEb7GtmjJO
    text-short-0.1.6.1-7WsaMddrP8QABQW4LD33dd
    th-lift-instances-0.1.20-Ix2EIDBaHlS3YmmEGgSZoJ time-1.12.2
    transformers-0.6.1.0 unix-2.8.4.0
    unix-compat-0.7.4.1-JHcud24i5tBJko1Lg5vR04
    unordered-containers-0.2.20.1-HfKtyefgs0b2egKrxLGXU0
    vector-0.13.2.0-7eILYIgfGZSAohY3MIpZY

haddock-interfaces:   /usr/share/doc/dhall/html/dhall.haddock
haddock-html:         /usr/share/doc/dhall/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

